@@ -1,5 +1,5 @@
 from django.contrib import admin
-from django.urls import path, include
+from django.urls import include, path
 from rest_framework import routers
 
 from testapp.api.urls import model_router
@@ -10,7 +10,6 @@ router.registry.extend(model_router.registry)
 urlpatterns = [
     # django Admin
     path('admin/', admin.site.urls),
-
     # REST Viewsets
     path('api/v1/', include(router.urls)),
 ]
